CompositeExecutor

Struct CompositeExecutor 

pub struct CompositeExecutor { /* private fields */ }
An executor that delegates instance creation to several other executors.

The executors are tried one after the other. If they return known whitelisted errors, we fall back to the next executor on the list.

Implementations

Source

impl CompositeExecutor

pub fn new(executors: Vec<Box<dyn Executor + Send + Sync>>) -> Self