ContractDebugInstanceState

Struct ContractDebugInstanceState 

pub struct ContractDebugInstanceState;

Implementations

Source

impl ContractDebugInstanceState

pub unsafe fn main_memory_load( mem_ptr: MemPtr, mem_length: MemLength, ) -> &'static [u8]

Interprets the input as a regular pointer.

Safety

The offset and the length must point to valid memory.

pub unsafe fn main_memory_store(offset: MemPtr, data: &[u8])

Interprets the input as a regular pointer and writes to current memory.

Safety

The offset and the length must point to valid memory.

pub fn main_memory_ptr(bytes: &[u8]) -> (MemPtr, MemLength)

pub fn main_memory_mut_ptr(bytes: &mut [u8]) -> (MemPtr, MemLength)

pub fn early_exit_panic(early_exit: VMHooksEarlyExit) -> !

pub fn breakpoint_panic(breakpoint_value: BreakpointValue) -> !