pub struct CompositeExecutor { /* private fields */ }Expand description
An executor that delegates instance creation to several other executors.
The executors are tried one after the other. If they return known whitelisted errors, we fall back to the next executor on the list.
Implementations